#
# spec file for package meteo
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           meteo
Version:        0.9.6
Release:        lp152.2.7
Summary:        Program to show the weather forecast of the next hours and days
License:        GPL-3.0-or-later
Group:          Productivity/Other
URL:            https://gitlab.com/bitseater
Source:         https://gitlab.com/bitseater/meteo/-/archive/%{version}/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  libxml2-tools
BuildRequires:  meson >= 0.40.0
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  vala
BuildRequires:  pkgconfig(appindicator3-0.1)
BuildRequires:  pkgconfig(champlain-0.12)
BuildRequires:  pkgconfig(clutter-1.0)
BuildRequires:  pkgconfig(clutter-gtk-1.0)
BuildRequires:  pkgconfig(geocode-glib-1.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(libsoup-2.4) > 2.54.1
BuildRequires:  pkgconfig(webkit2gtk-4.0)
Recommends:     %{name}-lang
Provides:       weather = %{version}
Obsoletes:      weather < %{version}

%description
A program which displays current weather, with information about temperature,
pressure, wind speed and direction, as well as sunrise and sunset times.

%lang_package

%prep
%setup -q -n meteo-%{version}

%build
%meson
%meson_build

%install
%meson_install
%suse_update_desktop_file -r com.gitlab.bitseater.meteo GTK Utility DesktopUtility
%find_lang com.gitlab.bitseater.meteo %{name}.lang
%fdupes %{buildroot}%{_datadir}

# dirlist HiDPI icons (see: hicolor/index.theme)
_dirlist=$PWD/dir.lst
pushd %{buildroot}
find ./ | while read _list; do
    echo $_list | grep '[0-9]\@[0-9]' || continue
    _path=$(echo $_list | sed 's/[^/]//')
    if ! ls ${_path%/*}; then
        grep -xqs "\%dir\ ${_path%/*}" $_dirlist || echo "%dir ${_path%/*}" >> $_dirlist
    fi
done
popd

%files -f dir.lst
%license COPYING
%doc AUTHORS README.md
%{_bindir}/com.gitlab.bitseater.meteo
%{_datadir}/applications/com.gitlab.bitseater.meteo.desktop
%{_datadir}/glib-2.0/schemas/com.gitlab.bitseater.meteo.gschema.xml
%{_datadir}/icons/hicolor/*/apps/com.gitlab.bitseater.meteo.??g
%{_datadir}/metainfo/com.gitlab.bitseater.meteo.appdata.xml

%files lang -f %{name}.lang

%changelog
* Mon Feb 18 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 0.9.6:
  * Read the Docs
* Mon Feb  4 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 0.9.5:
  * Update README
  * New icons
  * Update screenshots
* Thu Dec  6 2018 Alexei Podvalsky <avvissu@yandex.by>
- Update to 0.9.0:
  * Use hardcoded API key.
  * Fixed issues: 99, 100, 101, 102, 104, 105, 106.
* Wed Aug  8 2018 avvissu@yandex.by
- Update to 0.8.5:
  * Add support to RPM build.
  * Fixed issues: none.
- Switch to metainfo from appdata
* Wed Jun 13 2018 avvissu@yandex.by
- Update to 0.8.4:
  * Migration to GitLab.com.
  * Fixed issues: 98.
- Rename to meteo
* Thu Jun  7 2018 avvissu@yandex.by
- Switch to gitlab
- Spec file cleanup
* Thu Jun  7 2018 jengelh@inai.de
- Use noun phrasing.
* Mon Jun  4 2018 avvissu@yandex.by
- Update to 0.8.3:
  * Delete built-in API key which is blocked by OWM.
  * Fixed issues: 92, 96, 97.
* Tue May  8 2018 avvissu@yandex.by
- Update to 0.8.1:
  * Simplify gettext strings.
  * Add new update interval.
  * Add more information to indicator.
  * Add new translations.
  * Show location on indicator menu.
  * Add run on startup option.
  * Change wind speed units.
  * Fixed issues: 72, 74, 80, 81, 82, 83, 84, 85, 86, 87, 88.
* Mon Mar 26 2018 avvissu@yandex.by
- Update to 0.7.0:
  * Update de.po
  * Update screenshot and spanish po
  * Update lt.po
  * Update en.po
  * Several fixes to fr.po
  * Adding info to indicator. Fix issue #57
  * Fix issue #35 and #50
  * Add de.po
  * Add German
  * Remove granite
  * Update current cache file
  * Fix issue #58
  * Remove snap to separate repo
  * Snap without glib
* Fri Mar  2 2018 avvissu@yandex.by
- Update to 0.6.1:
  * New snapcraft file and update readme.md
  * Update support for appimage and snapcraft
  * Update readme and add appimage creator
  * Update README.md
  * Update appdata
* Fri Feb 23 2018 avvissu@yandex.by
- Update to 0.6.0:
  * Fix issue #52
- Add pkgconfig(granite)
* Fri Feb 16 2018 avvissu@yandex.by
- Update to 0.5.4:
  * Merge pull request #45 from welaq/patch-2
  * Update lt.po
  * Update flatpak manifiest.
  * Start minimized. Optional
  * Start minimized. Fix some issues with gresouce.
  * Merge pull request #41 from bil-elmoussaoui/gresource
  * load css from gresource, improve the constants file
  * Merge pull request #40 from bil-elmoussaoui/i18n
  * Update appdata and new screenshots.
  * Add files via upload
  * Delete screenshot_4.png
  * Updated appdata and screenshots
  * Avoid appstream validation
  * Improve appdata.xml
  * Change to validate Appstream
  * Merge pull request #37 from bil-elmoussaoui/patch-1
  * fix the indententation
* Fri Feb  9 2018 avvissu@yandex.by
- Update to 0.5.2:
  * Fix gnome issue
  * Update readme to v0.5
  * Release v0.5
  * Update Maps Layers and conectors
  * Change remove by destroy on update
  * Some minor fixes and maps views
  * Delete cmake support
  * Update to meson build
- Build with meson
- Add pkgconfig({webkit2gtk-4.0,appindicator3-0.1})
- Add  HiDPI icons
* Sun Jan 21 2018 avvissu@yandex.by
- Initial package
